@@ -8,11 +8,15 @@ impl Plugin for RapierRenderPlugin {
     fn build(&self, app: &mut AppBuilder) {
         app.add_system_to_stage(
             CoreStage::PreUpdate,
-            systems::create_collider_renders_system.system(),
+            systems::create_collider_renders_system
+                .system()
+                .label(systems::RenderSystems::CreateColliderRenders),
         );
         app.add_system_to_stage(
             CoreStage::PreUpdate,
-            systems::update_collider_render_mesh.system(),
+            systems::update_collider_render_mesh
+                .system()
+                .label(systems::RenderSystems::UpdateColliderRenderMesh),
         );
     }
 }
